summaryrefslogtreecommitdiffstats
path: root/libkonq/konq_popupmenu.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
commitfd3a982e26813f5bcc82c7e89ce6fa2ad44432bf (patch)
tree9eda848e56fcb862fdfdf479adeccd95b6fe387a /libkonq/konq_popupmenu.h
parent02f67d0e1355b79b1806746efb0f2f640e57f13d (diff)
downloadtdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.tar.gz
tdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1212480 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkonq/konq_popupmenu.h')
-rw-r--r--libkonq/konq_popupmenu.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/libkonq/konq_popupmenu.h b/libkonq/konq_popupmenu.h
index f1dc5ab63..ee528bc9e 100644
--- a/libkonq/konq_popupmenu.h
+++ b/libkonq/konq_popupmenu.h
@@ -69,7 +69,7 @@ public:
// WARNING: bitfield. Next item is 8
/**
* @deprecated lacks tqparentWidget pointer, and
* uses bool instead of KonqPopupFlags enum,
* might do strange things with the 'new window' action.
*/
@@ -89,7 +89,7 @@ public:
KURL viewURL,
KActionCollection & actions,
KNewMenu * newMenu,
- TQWidget * tqparentWidget,
+ TQWidget * parentWidget,
bool showPropertiesAndFileType = true ) KDE_DEPRECATED;
/**
@@ -99,7 +99,7 @@ public:
* @param viewURL the URL shown in the view, to test for RMB click on view background
* @param actions list of actions the caller wants to see in the menu
* @param newMenu "New" menu, shared with the File menu, in konqueror
* @param tqparentWidget the widget we're showing this popup for. Helps destroying
* the popup if the widget is destroyed before the popup.
* @param kpf flags from the KonqPopupFlags enum, set by the calling application
* @param f flags from the BrowserExtension enum, set by the calling part
@@ -117,7 +117,7 @@ public:
const KURL& viewURL,
KActionCollection & actions,
KNewMenu * newMenu,
- TQWidget * tqparentWidget,
+ TQWidget * parentWidget,
KonqPopupFlags kpf,
KParts::BrowserExtension::PopupFlags f /*= KParts::BrowserExtension::DefaultPopupItems*/);
@@ -177,7 +177,7 @@ protected:
KActionCollection m_ownActions;
private:
- void init (TQWidget * tqparentWidget, KonqPopupFlags kpf, KParts::BrowserExtension::PopupFlags itemFlags);
+ void init (TQWidget * parentWidget, KonqPopupFlags kpf, KParts::BrowserExtension::PopupFlags itemFlags);
void setup(KonqPopupFlags kpf);
void addPlugins( );
int insertServicesSubmenus(const TQMap<TQString, ServiceList>& list, TQDomElement& menu, bool isBuiltin);
@@ -69,7 +69,7 @@ public:
// WARNING: bitfield. Next item is 8
/**
- * @deprecated lacks tqparentWidget pointer, and
+ * @deprecated lacks parentWidget pointer, and
* uses bool instead of KonqPopupFlags enum,
* might do strange things with the 'new window' action.
@@ -99,7 +99,7 @@ public:
* @param actions list of actions the caller wants to see in the menu
* @param newMenu "New" menu, shared with the File menu, in konqueror
- * @param tqparentWidget the widget we're showing this popup for. Helps destroying
+ * @param parentWidget the widget we're showing this popup for. Helps destroying
* the popup if the widget is destroyed before the popup.
* @param kpf flags from the KonqPopupFlags enum, set by the calling application